from paste.session import SessionMiddleware
from paste.fixture import TestApp
import six

info = []

def wsgi_app(environ, start_response):
    pi = environ.get('PATH_INFO', '')
    if pi in ('/get1', '/get2'):
        if pi == '/get1':
            sess = environ['paste.session.factory']()
        start_response('200 OK', [('content-type', 'text/plain')])
        if pi == '/get2':
            sess = environ['paste.session.factory']()
        if 'info' in sess:
            body = str(sess['info'])
            if six.PY3:
                body = body.encode('utf8')
            return [body]
        else:
            return [b'no-info']
    if pi in ('/put1', '/put2'):
        if pi == '/put1':
            sess = environ['paste.session.factory']()
            sess['info']  = info[0]
        start_response('200 OK', [('content-type', 'text/plain')])
        if pi == '/put2':
            sess = environ['paste.session.factory']()
            sess['info']  = info[0]
        return [b'foo']

wsgi_app = SessionMiddleware(wsgi_app)

def test_app1():
    app = TestApp(wsgi_app)
    res = app.get('/get1')
    assert res.body == b'no-info'
    res = app.get('/get2')
    assert res.body ==b'no-info'
    info[:] = ['test']
    res = app.get('/put1')
    res = app.get('/get1')
    assert res.body == b'test'
    res = app.get('/get2')
    assert res.body == b'test'

def test_app2():
    app = TestApp(wsgi_app)
    info[:] = ['fluff']
    res = app.get('/put2')
    res = app.get('/get1')
    assert res.body == b'fluff'
    res = app.get('/get2')
    assert res.body == b'fluff'





import os
import sys

import pytest

from paste.cgiapp import CGIApplication, CGIError
from paste.fixture import *

data_dir = os.path.join(os.path.dirname(__file__), 'cgiapp_data')

# these CGI scripts can't work on Windows or Jython
if sys.platform != 'win32' and not sys.platform.startswith('java'):

    # Ensure the CGI scripts are called with the same python interpreter. Put a
    # symlink to the interpreter executable into the path...
    def setup_module():
        global oldpath, pyexelink
        oldpath = os.environ.get('PATH', None)
        os.environ['PATH'] = data_dir + os.path.pathsep + oldpath
        pyexelink = os.path.join(data_dir, "python")
        try:
            os.unlink(pyexelink)
        except OSError:
            pass
        os.symlink(sys.executable, pyexelink)

    # ... and clean up again.
    def teardown_module():
        global oldpath, pyexelink
        os.unlink(pyexelink)
        if oldpath is not None:
            os.environ['PATH'] = oldpath
        else:
            del os.environ['PATH']

    def test_ok():
        app = TestApp(CGIApplication({}, script='ok.cgi', path=[data_dir]))
        res = app.get('')
        assert res.header('content-type') == 'text/html; charset=UTF-8'
        assert res.full_status == '200 Okay'
        assert 'This is the body' in res

    def test_form():
        app = TestApp(CGIApplication({}, script='form.cgi', path=[data_dir]))
        res = app.post('', params={'name': b'joe'},
                       upload_files=[('up', 'file.txt', b'x'*10000)])
        assert 'file.txt' in res
        assert 'joe' in res
        assert 'x'*10000 in res

    def test_error():
        app = TestApp(CGIApplication({}, script='error.cgi', path=[data_dir]))
        pytest.raises(CGIError, app.get, '', status=500)

    def test_stderr():
        app = TestApp(CGIApplication({}, script='stderr.cgi', path=[data_dir]))
        res = app.get('', expect_errors=True)
        assert res.status == 500
        assert 'error' in res
        assert 'some data' in res.errors
